Scene Data Components
=====================

.. autoclass:: yt_idv.scene_data.base_data.SceneData
.. autoclass:: yt_idv.scene_data.block_collection.BlockCollection
.. autoclass:: yt_idv.scene_data.box.BoxData
.. autoclass:: yt_idv.scene_data.line.LineData
.. autoclass:: yt_idv.scene_data.mesh.MeshData
.. autoclass:: yt_idv.scene_data.rgba.RGBAData
.. autoclass:: yt_idv.scene_data.text_characters.TextCharacters
